#!/usr/bin/env python
# GladeVcp Widget - calculator input
# This widgets allows simple calculations.
# The result can be returned for further use.
# Origially to be used as numerical input on a touch screen.
#
# Copyright (c) 2012 Chris Morley
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

import sys,os,pango
import math
import linuxcnc

datadir = os.path.abspath(os.path.dirname(__file__))

try:
    import gobject,gtk
except:
    print('GTK not available')
    sys.exit(1)

class HAL_DRO(gtk.VBox):
    __gtype_name__ = 'HAL_DRO'
    __gproperties__ = {
        'is_editable' : ( gobject.TYPE_BOOLEAN, 'Is Editable', 'Ability to use a keyboard to enter data',
                    False, gobject.PARAM_READWRITE | gobject.PARAM_CONSTRUCT),
		'font' : ( gobject.TYPE_STRING, 'Pango Font', 'Display font to use',
                "sans 12", gobject.PARAM_READWRITE|gobject.PARAM_CONSTRUCT),
    }
    __gproperties = __gproperties__

    def __init__(self, *a, **kw):
        gtk.VBox.__init__(self, *a, **kw)
        self.emc = linuxcnc
        self.status = self.emc.stat()
        self.eval_string=""
        self.font="sans 12"
        self.wTree = gtk.Builder()
        self.wTree.add_from_file(os.path.join(datadir, "dro.glade") )
        window = self.wTree.get_object("DRO_box")
        window.reparent(self)
        gobject.timeout_add(100, self.periodic)
    def do_get_property(self, property):
        name = property.name.replace('-', '_')
        if name in self.__gproperties.keys():
            return getattr(self, name)
        else:
            raise AttributeError('unknown property %s' % property.name)

    def do_set_property(self, property, value):
        name = property.name.replace('-', '_')
        if name == 'is_editable':
            pass
        if name == 'font':
            pass

    def periodic(self):
        try:
            self.status.poll()
            sys = self.get_current_system()
        except:
            sys = 0
        systemlabel = ("Machine","G54","G55","G56","G57","G58","G59","G59.1","G59.2","G59.3")
        self.wTree.get_object("cur_system").set_text(systemlabel[sys])
        for axis in(0,1,2):
            data = self.get_tool_offset(axis)
            self.wTree.get_object("tool_offset%d"%axis).set_text(str(data))

            data = self.get_g5x_offset(axis)
            text = "% 9.4f"% (data)
            self.wTree.get_object("g5x_offset%d"%axis).set_text(text)

            data = self.get_axis_position(axis)
            text = "% 9.4f"% (data)
            self.wTree.get_object("axis_pos%d"%axis).set_text(text)
        return True

    def get_current_system(self):
        g = self.status.gcodes
        for i in g:
            if i >= 540 and i <= 590:
                return i/10 - 53
            elif i >= 590 and i <= 593:
                return i - 584
        return 1

    def get_tool_offset(self,index):
        return self.status.tool_offset[index]

    def get_g5x_offset(self,index):
        return self.status.g5x_offset[index]
    
    def get_axis_position(self,index):
        p = self.status.actual_position
        return p[index]

# for testing without glade editor:
def main():
    window = gtk.Dialog("My dialog",
                   None,
                   gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
                   (gtk.STOCK_CANCEL, gtk.RESPONSE_REJECT,
                    gtk.STOCK_OK, gtk.RESPONSE_ACCEPT))
    dro = HAL_DRO()
    
    window.vbox.add(dro)
    window.connect("destroy", gtk.main_quit)

    window.show_all()
    response = window.run()
    if response == gtk.RESPONSE_ACCEPT:
       print "ok"
    else:
       print "cancel"

if __name__ == "__main__":	
    main()


